@@ -241,3 +241,35 @@ class LoadMaster(HttpClient):
             return ApiXmlHelper.parse_to_dict(response)
         else:
             raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
+
+    def upload_template(self, file):
+        response = self._post('/uploadtemplate', file)
+        return ApiXmlHelper.is_successful(response)
+
+    def list_templates(self):
+        response = self._get('/listtemplates')
+        if ApiXmlHelper.is_successful(response):
+            return ApiXmlHelper.parse_to_dict(response)
+        else:
+            raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
+
+    def delete_template(self, template_name):
+        params = {'name': template_name}
+        response = self._get('/deltemplate', parameters=params)
+        if ApiXmlHelper.is_successful(response):
+            return ApiXmlHelper.parse_to_dict(response)
+        else:
+            raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
+
+    def apply_template(self, virtual_ip, port, protocol, template_name):
+        params = {
+            'vs': virtual_ip,
+            'port': port,
+            'prot': protocol,
+            'name': template_name,
+        }
+        response = self._get('/addvs', parameters=params)
+        if ApiXmlHelper.is_successful(response):
+            return ApiXmlHelper.parse_to_dict(response)
+        else:
+            raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
